@@ -2,7 +2,7 @@ use strict;
 use warnings;
 use 5.014;
 
-package App::af 0.06 {
+package App::af 0.07 {
 
   use Moose::Role;
   use namespace::autoclean;
@@ -45,7 +45,7 @@ package App::af 0.06 {
       $name =~ s/_/-/g;
       $name .= '|' . $attr->short    if $attr->short;
       $name .= "=" . $attr->opt_type if $attr->opt_type;
-      if($attr->opt_type =~ /\{/)
+      if($attr->is_array)
       {
         my @array;
         $args{$attr->name} = \@array;
@@ -211,6 +211,16 @@ package App::af::opt {
     isa     => 'Str',
     default => '',
   );
+  
+  has is_array => (
+    is      => 'rw',
+    isa     => 'Int',
+    lazy    => 1,
+    default => sub {
+      my($self) = @_;
+      int $self->opt_type =~ /\{/;
+    },
+  );
 
 }
 
@@ -228,7 +238,7 @@ App::af - Command line tool for alienfile
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
