@@ -11,7 +11,7 @@ use File::chdir;
 # VERSION
 
 
-package App::af::download 0.06 {
+package App::af::download 0.07 {
   use Moose;
   use namespace::autoclean;
   use MooseX::Types::Path::Tiny qw( AbsPath );
@@ -88,6 +88,7 @@ package App::af::install {
   use File::Temp qw( tempdir );
   use MooseX::Types::Path::Tiny qw( AbsPath );
   use YAML qw( Dump );
+  use Path::Tiny qw( path );
   
   with 'App::af';
   with 'App::af::role::alienfile';
@@ -152,12 +153,42 @@ package App::af::install {
     opt_type => 's{2}',
   );
   
+  has I => (
+    is       => 'ro',
+    isa      => 'ArrayRef[Str]',
+    traits   => ['App::af::opt'],
+    opt_type => 's',
+    is_array => 1,
+  );
+  
+  has blib => (
+    is       => 'ro',
+    isa      => 'Int',
+    traits   => ['App::af::opt'],
+  );
+  
   sub main
   {
     my($self) = @_;
-    
+  
     local $ENV{ALIEN_INSTALL_TYPE} = $ENV{ALIEN_INSTALL_TYPE};
     
+    foreach my $inc (reverse @{ $self->I })
+    {
+      require lib;
+      lib->import($inc);
+    }
+    
+    if($self->blib)
+    {
+      require blib;
+      blib->import;
+    }
+
+    # make sure @INC entries are absolute, since $build
+    # may do a lot of directory changes    
+    @INC = map { ref $_ ? $_ : path($_)->absolute->stringify } @INC;
+    
     if(defined $self->type)
     {
       unless($self->type =~ /^(share|system)$/)
@@ -178,10 +209,21 @@ package App::af::install {
     $self->prefix($prefix) if defined($prefix) && ! $self->prefix;
     
     my @all_hooks = qw(
-      download fetch decode prefer extract patch
+      probe download fetch decode prefer extract patch
       build stage gather_share gather_system
     );
     
+    my $repl = sub {
+      no warnings 'once';
+      require Shell::Perl;
+      my $pirl = Shell::Perl->new(on_quit => 'return');
+      $pirl->set_package("App::af::pirl");
+      $App::af::pirl::build = $build;
+      $App::af::pirl::meta  = $build->meta;
+      eval { $pirl->run };
+      warn $@ if $@;
+    };
+    
     while(@{ $self->before })
     {
       my $hook    = shift @{ $self->before };
@@ -196,7 +238,9 @@ package App::af::install {
           my($build) = @_;
           $build->log(" [ before @{[ $build->hook_prop->{name} ]} ] + $command");
           $build->checkpoint;
-          $build->system($command);
+          $command eq ':repl'
+            ? $repl->()
+            : $build->system($command);
         }
       ) for @hook;
     }
@@ -217,7 +261,9 @@ package App::af::install {
           my $error = $@;
           $build->log(" [ after @{[ $build->hook_prop->{name} ]} ] + $command");
           $build->checkpoint;
-          $build->system($command);
+          $command eq ':repl'
+            ? $repl->()
+            : $build->system($command);
           die $error if $error;
           $ret;
         },
@@ -232,7 +278,7 @@ package App::af::install {
     
     unless(defined $self->prefix)
     {
-      say STDERR "You must specify a prefix with --prefix";
+      say STDERR "You must specify a prefix with --prefix or use --dry-run";
       return 2;
     }
     
@@ -563,7 +609,7 @@ af - Command line tool for alienfile
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -631,8 +677,10 @@ if not specified.
 
  af install
    [ ( -f | --file )  alienfile |  ( -c | --class ) class ]
-   [ --stage directory ] [ --prefix directory ] [ --type ( share | system ) ]
-   [ --root directory ] [ --before hook command ] [ --after hook command ]
+   [ --prefix directory | --dry-run ] [ --stage directory ]
+   [ --type ( share | system ) ] [ --root directory ] 
+   [ --before hook command ] [ --after hook command ]
+   [ -I lib ] [ --blib ]
 
 =head3 description
 
@@ -686,7 +734,9 @@ extraction:
 
 The build configuration is check pointed, so you can read the install 
 and runtime properties in the C<state.json> file in the build root.
-Use * or % as the hook to run the command before all hooks.
+Use * or % as the hook to run the command before all hooks.  You can
+use C<:repl> as the command to open up a Perl REPL (Read-Eval-Print-Loop)
+to inspect the C<$build> and C<$meta> objects.
 
 =head4 --after
 
@@ -698,7 +748,17 @@ interactive shell after the build has completed:
 
 The build configuration is check pointed, so you can read the install 
 and runtime properties in the C<state.json> file in the build root.
-Use * or % as the hook to run the command before all hooks.
+Use * or % as the hook to run the command before all hooks.  You can
+use C<:repl> as the command to open up a Perl REPL (Read-Eval-Print-Loop)
+to inspect the C<$build> and C<$meta> objects.
+
+=head4 -I
+
+Add directory to the Perl search lib (like -I on L<perl>).
+
+=head4 --blib
+
+Use the blib from the current directory.
 
 =head2 requires
 
